skeleton_shimmer library

Shimmer loading effect with an API compatible with the shimmer package, plus skeleton placeholder primitives and reduced-motion support.

Classes

Shimmer
Paints an animated gradient sweep over its child's opaque pixels, producing the shimmer loading effect.
SkeletonBox
A rounded rectangle placeholder to put under a Shimmer.
SkeletonCircle
A circular placeholder, e.g. for an avatar.
SkeletonLine
A single line of placeholder text.

Enums

ShimmerDirection
Direction the highlight sweeps across the child.